<?php
/**
 * <meta content="charset=UTF-8">
 * @package Welcart
 * @subpackage PayPal Vermilion Theme
 */
if(!defined('USCES_VERSION')) return;

include( get_template_directory() . '/inc/add_functions1.php' );
include( get_template_directory() . '/inc/add_functions2.php' );

/***********************************************************
* content_width
***********************************************************/
if ( ! isset( $content_width ) )
	$content_width = 980;

/***********************************************************
* welcart_setup
***********************************************************/
add_action( 'after_setup_theme', 'welcart_setup' );

if ( ! function_exists( 'welcart_setup' ) ):
function welcart_setup() {

	load_theme_textdomain( 'uscestheme', get_template_directory() . '/languages' );
	
	add_editor_style();

	require( get_template_directory() . '/inc/theme-options.php' );

	add_theme_support( 'post-thumbnails' );

	register_nav_menus( array(
		'header' => __('Header Navigation', 'usces' ),
		'footer' => __('Footer Navigation', 'usces' ),
	) );

}
endif;


/***********************************************************
* wp_page_menu() : welcart_page_menu_args
***********************************************************/
function welcart_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'welcart_page_menu_args' );

/***********************************************************
* excerpt
***********************************************************/
if ( ! function_exists( 'welcart_assistance_excerpt_length' ) ) {
	function welcart_assistance_excerpt_length( $length ) {
		return 10;
	}
}

if ( ! function_exists( 'welcart_assistance_excerpt_mblength' ) ) {
	function welcart_assistance_excerpt_mblength( $length ) {
		return 40;
	}
}

if ( ! function_exists( 'welcart_excerpt_length' ) ) {
	function welcart_excerpt_length( $length ) {
		return 40;
	}
}
add_filter( 'excerpt_length', 'welcart_excerpt_length' );

if ( ! function_exists( 'welcart_continue_reading_link' ) ) {
	function welcart_continue_reading_link() {
		return ' <a href="'. get_permalink() . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'uscestheme' ) . '</a>';
	}
}

if ( ! function_exists( 'welcart_auto_excerpt_more' ) ) {
	function welcart_auto_excerpt_more( $more ) {
		return ' &hellip;' . welcart_continue_reading_link();
	}
}
add_filter( 'excerpt_more', 'welcart_auto_excerpt_more' );

if ( ! function_exists( 'welcart_custom_excerpt_more' ) ) {
	function welcart_custom_excerpt_more( $output ) {
		if ( has_excerpt() && ! is_attachment() ) {
			$output .= welcart_continue_reading_link();
		}
		return $output;
	}
}
add_filter( 'get_the_excerpt', 'welcart_custom_excerpt_more' );

/***********************************************************
* comment
***********************************************************/
//if ( ! function_exists( 'welcart_comment' ) ) :
function welcart_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 40 ); ?>
			<?php printf( __( '%s <span class="says">says:</span>', 'uscestheme' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php _e( 'Your comment is awaiting moderation.', 'uscestheme' ); ?></em>
			<br />
		<?php endif; ?>

		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'uscestheme' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'uscestheme' ), ' ' );
			?>
		</div><!-- .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'uscestheme' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'uscestheme'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
//endif;

/***********************************************************
* Review
***********************************************************/
if ( ! function_exists( 'wc_review' ) ) :
function wc_review( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-review-<?php comment_ID(); ?>">
		<div id="review-<?php comment_ID(); ?>">
		<div class="review-author vcard">
			<?php echo get_avatar( $comment, 40 ); ?>
			<?php printf( __( '%s <span class="says">says:</span>', 'uscestheme' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- .review-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php _e( 'Your review is awaiting moderation.', 'uscestheme' ); ?></em>
			<br />
		<?php endif; ?>

		<div class="review-meta reviewmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'uscestheme' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'uscestheme' ), ' ' );
			?>
		</div><!-- .review-meta .reviewmetadata -->

		<div class="review-body"><?php comment_text(); ?></div>

	</div><!-- #review-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'uscestheme' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'uscestheme'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

/***********************************************************
* widgets
***********************************************************/
function welcart_widgets_init() {
	// Area 1, sidebar-homemiddle.
	register_sidebar(array(
		'name' => __( 'Widget Area for Home Middle', 'uscestheme' ),
		'id' => 'home-middle-widget-area',
		'description' => __( 'widget area for home middle', 'uscestheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget_title">',
		'after_title' => '</h3>',
	));

	// Area 2, sidebar-homebottom.
	register_sidebar( array(
		'name' => __( 'Widget Area for Home Bottom', 'uscestheme' ),
		'id' => 'home-bottom-widget-area',
		'description' => __( 'widget area for home bottom', 'uscestheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget_title">',
		'after_title' => '</h3>',
	) );

	// Area 3, sidebar-item.
	register_sidebar( array(
		'name' => __( 'Widget Area for Item Page', 'uscestheme' ),
		'id' => 'item-widget-area',
		'description' => __( 'widget area for item page', 'uscestheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget_title">',
		'after_title' => '</h3>',
	) );

	// Area 4, sidebar-member.
	register_sidebar( array(
		'name' => __( 'Widget Area for Member Page', 'uscestheme' ),
		'id' => 'member-widget-area',
		'description' => __( 'widget area for member page', 'uscestheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget_title">',
		'after_title' => '</h3>',
	) );

	// Area 5, sidebar.
	register_sidebar( array(
		'name' => __( 'Widget Area for Other Page', 'uscestheme' ),
		'id' => 'otherbottom-widget-area',
		'description' => __( 'widget area for other page', 'uscestheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget_title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'welcart_widgets_init' );

/***********************************************************
* welcart_remove_recent_comments_style
***********************************************************/
function welcart_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'welcart_remove_recent_comments_style' );

/***********************************************************
* welcart_posted_on
***********************************************************/
if ( ! function_exists( 'welcart_posted_on' ) ) :
function welcart_posted_on() {
	printf( __( '<span class="%1$s">Posted on</span> %2$s <span class="meta-sep">by</span> %3$s', 'uscestheme' ),
		'meta-prep meta-prep-author',
		sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date">%3$s</span></a>',
			get_permalink(),
			esc_attr( get_the_time() ),
			get_the_date()
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'uscestheme' ), get_the_author() ),
			get_the_author()
		)
	);
}
endif;

/***********************************************************
* welcart_posted_in
***********************************************************/
if ( ! function_exists( 'welcart_posted_in' ) ) :
function welcart_posted_in() {
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'This entry was posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'uscestheme' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'This entry was posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'uscestheme' );
	} else {
		$posted_in = __( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'uscestheme' );
	}

	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;

/***********************************************************
* SSL
***********************************************************/
if( $usces->options['use_ssl'] ){
	add_action('init', 'usces_ob_start');
	function usces_ob_start(){
		global $usces;
		if( $usces->use_ssl && ($usces->is_cart_or_member_page($_SERVER['REQUEST_URI']) || $usces->is_inquiry_page($_SERVER['REQUEST_URI'])) )
			ob_start('usces_ob_callback');
	}
	function usces_ob_callback($buffer){
		global $usces;
		$pattern = array(
			'|(<[^<]*)href=\"'.get_option('siteurl').'([^>]*)\.css([^>]*>)|', 
			'|(<[^<]*)src=\"'.get_option('siteurl').'([^>]*>)|'
		);
		$replacement = array(
			'${1}href="'.USCES_SSL_URL_ADMIN.'${2}.css${3}', 
			'${1}src="'.USCES_SSL_URL_ADMIN.'${2}'
		);
		$buffer = preg_replace($pattern, $replacement, $buffer);
		return $buffer;
	}
}

/***********************************************************
* Welcart Widget
***********************************************************/
add_filter('widget_categories_dropdown_args', 'welcart_categories_args'); 
add_filter('widget_categories_args', 'welcart_categories_args'); 
function welcart_categories_args( $args ){ 
	global $usces;
	$ids = $usces->get_item_cat_ids();
	$ids[] = USCES_ITEM_CAT_PARENT_ID;
	$args['exclude'] = $ids;
	return $args;
}

add_filter('getarchives_where', 'welcart_getarchives_where');
function welcart_getarchives_where( $r ){
	$where = "WHERE post_type = 'post' AND post_status = 'publish' AND post_mime_type <> 'item' ";
	return $where;
}

add_filter('widget_tag_cloud_args', 'welcart_tag_cloud_args');
function welcart_tag_cloud_args( $args ){
	global $usces;
	if( 'category' == $args['taxonomy']){
		$ids = $usces->get_item_cat_ids();
		$ids[] = USCES_ITEM_CAT_PARENT_ID;
		$args['exclude'] = $ids;
	}else if( 'post_tag' == $args['taxonomy']){
		$ids = $usces->get_item_post_ids();
		$tobs = wp_get_object_terms($ids, 'post_tag');
		foreach( $tobs as $ob ){
			$tids[] = $ob->term_id;
		}
		$args['exclude'] = $tids;
	}
	return $args;
}


/***********************************************************
* ベストセラーにサムネイルを表示する
***********************************************************/
add_filter ( 'usces_widget_bestseller_auto_text', 'my_bestseller_auto_text', 10, 2 );
function my_bestseller_auto_text($title, $post_id) {
	$post = get_post($post_id);
	$title = usces_the_itemImage(0, 133, 133, $post, 'return') . $title;
	return $title;
}

/***********************************************************
* パンクズリスト
***********************************************************/
global $cat_depth;
function breadcrumb($divOption = array("id" => "breadcrumb", "class" => "clearfix")){
	global $post;
	$str ='';
	if(!is_home()&&!is_admin()){ /* !is_admin は管理ページ以外という条件分岐 */
		$tagAttribute = '';
		foreach($divOption as $attrName => $attrValue){
			$tagAttribute .= sprintf(' %s="%s"', $attrName, $attrValue);
		}
		$str.= '<div'. $tagAttribute .'>';
		$str.= '<ul>';
		$str.= '<li><a href="'. home_url() .'/">HOME</a></li>';
		$str.= '<li class="arrow">&gt;</li>';
 
		if(is_category()) {								//カテゴリーのアーカイブページ
			$cat = get_queried_object();
			if($cat -> parent != 0){
				$ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' ));
				foreach($ancestors as $ancestor){
					$str.='<li><a href="'. get_category_link($ancestor) .'">'. get_cat_name($ancestor) .'</a></li>';
					$str.='<li class="arrow">&gt;</li>';
				}
			}
			$str.='<li>'. $cat -> name . '</li>';
		} elseif( is_single() && usces_is_item($post->ID) ){ //商品詳細ページ
		
			global $cat_depth;
			get_item_category_depth( 'itemgenre', true );
			$cats = get_the_category( $post->ID );
			$targets = array();
			foreach( $cats as $cat ){
				if( !isset( $cat_depth[$cat->term_id] ) )
					continue;
				
				$ob = $cat_depth[$cat->term_id];
				$targets[$ob->item_depth] = $ob;
			}
			ksort($targets);
			
			foreach($targets as $term_id => $target){
				$str .= '<li><a href="' . get_category_link( $term_id ) . '">' . $target->name . '</a></li>';
				$str.='<li class="arrow">&gt;</li>';
			}
			$str .= '<li>' . esc_html($post->post_title) . '</li>';
			
		} elseif(is_single()){							//ブログの個別記事ページ
			$categories = get_the_category($post->ID);
			$cat = $categories[0];
			if($cat -> parent != 0){
				$ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' ));
				foreach($ancestors as $ancestor){
					$str.='<li><a href="'. get_category_link($ancestor).'">'. get_cat_name($ancestor). '</a></li>';
					$str.='<li class="arrow">&gt;</li>';
				}
			}
			$str.='<li><a href="'. get_category_link($cat -> term_id). '">'. $cat-> cat_name . '</a></li>';
			$str.='<li class="arrow">&gt;</li>';
			$str.= '<li>'. $post -> post_title .'</li>';
		} elseif(is_page()){							//固定ページ
			if($post -> post_parent != 0 ){
				$ancestors = array_reverse(get_post_ancestors( $post->ID ));
				foreach($ancestors as $ancestor){
					$str.='<li><a href="'. get_permalink($ancestor).'">'. get_the_title($ancestor) .'</a></li>';
					$str.='<li class="arrow">&gt;</li>';
				}
			}
			$str.= '<li>'. $post -> post_title .'</li>';
		} elseif(is_date()){							//日付ベースのアーカイブページ
			if(get_query_var('day') != 0){				//年別アーカイブ
				$str.='<li><a href="'. get_year_link(get_query_var('year')). '">' . get_query_var('year'). '年</a></li>';
				$str.='<li class="arrow">&gt;</li>';
				$str.='<li><a href="'. get_month_link(get_query_var('year'), get_query_var('monthnum')). '">'. get_query_var('monthnum') .'月</a></li>';
				$str.='<li class="arrow">&gt;</li>';
				$str.='<li>'. get_query_var('day'). '日</li>';
			} elseif(get_query_var('monthnum') != 0){	//月別アーカイブ
				$str.='<li><a href="'. get_year_link(get_query_var('year')) .'">'. get_query_var('year') .'年</a></li>';
				$str.='<li class="arrow">&gt;</li>';
				$str.='<li>'. get_query_var('monthnum'). '月</li>';
			} else {									//年別アーカイブ
				$str.='<li>'. get_query_var('year') .'年</li>';
			}
		} elseif(is_search()) {							//検索結果表示ページ
			$str.='<li>「'. get_search_query() .'」で検索した結果</li>';
		} elseif(is_author()){							//投稿者のアーカイブページ
			$str .='<li>投稿者 : '. get_the_author_meta('display_name', get_query_var('author')).'</li>';
		} elseif(is_tag()){								//タグのアーカイブページ
			$str.='<li>タグ : '. single_tag_title( '' , false ). '</li>';
		} elseif(is_attachment()){						//添付ファイルページ
			$str.= '<li>'. $post -> post_title .'</li>';
		} elseif(is_404()){								//404 Not Found ページ
			$str.='<li>404 Not found</li>';
		} else{											//その他
			$str.='<li>'. wp_title('', true) .'</li>';
		}
		$str.='</ul>';
		$str.='</div>';
	}
	echo $str;
}

function get_item_category_depth( $parent = 'itemgenre', $first = true ){
	global $cat_depth;
	$cat_depth = array();
	$depth = 1;
	$cat_ob = get_category_by_slug( $parent );
	$cat_ob->item_depth = $depth;
	if( $first )
		$cat_depth[$cat_ob->term_id] = $cat_ob;
		
	add_item_category_depth($cat_ob, $depth);
	ksort($cat_depth);
	
		
}

function add_item_category_depth($parent_ob, $depth){
	global $cat_depth;
	$depth++;
	$childargs = array(
		'type'                     => 'post',
		'parent'                   => $parent_ob->term_id,
		'orderby'                  => 'name',
		'order'                    => 'ASC',
		'hide_empty'               => 0,
		'pad_counts'               => false );
	$childcats = get_categories( $childargs );
	if( 0 < count($childcats) ){
		foreach( $childcats as $childcat ){
			if( 100 < $depth ) break;
				
			$childcat->item_depth = $depth;
			$cat_depth[$childcat->term_id] = $childcat;
			add_item_category_depth($childcat, $depth);
		}
	}	
}

